==> teradataml-16.20.0.1.post0-py3-none-any.whl: teradataml/analytics/mle/PathAnalyzer.py <==
#!/usr/bin/python
# ################################################################## 
# 
# Copyright 2018 Teradata. All rights reserved.
# TERADATA CONFIDENTIAL AND TRADE SECRET
# 
# Primary Owner: Pankaj Purandare (pankajvinod.purandare@teradata.com)
# Secondary Owner: Mounika Kotha (mounika.kotha@teradata.com)
# 
# Version: 1.2
# Function Version: 1.8
# 
# ################################################################## 

from teradataml.common.wrapper_utils import AnalyticsWrapperUtils
from teradataml.common.utils import UtilFuncs
from teradataml.context.context import *
from teradataml.dataframe.dataframe import DataFrame
from teradataml.common.aed_utils import AedUtils
from teradataml.analytics.analytic_query_generator import AnalyticQueryGenerator
from teradataml.common.exceptions import TeradataMlException
from teradataml.common.messages import Messages
from teradataml.common.messagecodes import MessageCodes
from teradataml.common.constants import TeradataConstants
from teradataml.dataframe.dataframe_utils import DataFrameUtils as df_utils
from teradataml.options.display import display

class PathAnalyzer:
    
    def __init__(self,
        data = None,
        seq_column = None,
        count_column = None,
        hash = False,
        delimiter = ",",
        data_sequence_column = None):
        """
        DESCRIPTION:
            This function generates the children, parent for a particular node and
            calculates its depth and number of visits.
            The PathAnalyzer function:
                - Inputs a set of paths to the PathGenerator function.
                - Inputs the output to the PathSummarizer function.
                - Inputs the output to the PathStart function, which outputs, for each
                parent, all children and the number of times that the user traveled
                each child.
        
        
        PARAMETERS:
            data:
                Required Argument.
                Specifies either the name of the input teradataml DataFrame
                or processed NPath output. The input teradataml DataFrame contains
                the paths to analyze. Each path is a string of alphanumeric symbols
                that represents an ordered sequence of page views (or actions).
                Typically, each symbol is a code that represents a unique page
                view.
                If you would like to use output of NPath, then it must be processed
                to select two columns; the column that contains the paths
                (seq_column) and the column that contains the number of times
                a path was traveled (count_column), which should be grouped by
                seq_column, so that the input teradataml DataFrame has
                one row for each unique path traveled on a web site.
            
            seq_column:
                Required Argument.
                Specifies the name of the input teradataml DataFrame column that
                contains the paths.
                Types: str
            
            count_column:
                Required Argument.
                Specifies the name of the input teradataml DataFrame column that
                contains the number of times a path was traveled.
                Types: str
            
            hash:
                Optional Argument.
                Specifies whether to include the hash code of the output column node. 
                Default Value: False
                Types: bool
            
            delimiter:
                Optional Argument.
                Specifies the single-character delimiter that separates symbols in 
                the path string.
                Note: Do not use any of the following characters as delimiter
                (they cause the function to fail): Asterisk (*), Plus (+),
                Left parenthesis ((), Right parenthesis ()), Single quotation mark ('),
                Escaped single quotation mark (\\'), Backslash (\\)
                Default Value: ","
                Types: str
            
            data_sequence_column:
                Optional Argument.
                Specifies the list of column(s) that uniquely identifies each row of 
                the input argument "data". The argument is used to ensure 
                deterministic results for functions which produce results that vary 
                from run to run.
                Types: str OR list of Strings (str)
        
        RETURNS:
            Instance of PathAnalyzer.
            Output teradataml DataFrames can be accessed using attribute
            references, such as PathAnalyzerObj.<attribute_name>.
            Output teradataml DataFrame attribute name is:
                output_table
        
        
        RAISES:
            TeradataMlException
        
        
        EXAMPLES:
            # Load example data.
            load_example_data("pathanalyzer", "clickstream1")
            
            # Create teradataml DataFrame objects.
            # The table contains clickstream data, where the "path" column
            # contains symbols for the pages that the customer clicked.
            clickstream1 = DataFrame.from_table("clickstream1")
            
            # Example 1 - Let's analyze the Paths taken for a parent, children
            #             in this clickstream data, to reach to a page.
            PathAnalyzer_out = PathAnalyzer(data = clickstream1,
                                            seq_column = "path",
                                            count_column = "cnt",
                                            hash = False,
                                            delimiter = ","
                                            )

            # Print the results
            PathAnalyzer_out
        
        """
        self.data  = data 
        self.seq_column  = seq_column 
        self.count_column  = count_column 
        self.hash  = hash 
        self.delimiter  = delimiter 
        self.data_sequence_column  = data_sequence_column 
        
        # Create TeradataPyWrapperUtils instance which contains validation functions.
        self.__awu = AnalyticsWrapperUtils()
        self.__aed_utils = AedUtils()
        
        # Create argument information matrix to do parameter checking
        self.__arg_info_matrix = []
        self.__arg_info_matrix.append(["data", self.data, False, (DataFrame)])
        self.__arg_info_matrix.append(["seq_column", self.seq_column, False, (str)])
        self.__arg_info_matrix.append(["count_column", self.count_column, False, (str)])
        self.__arg_info_matrix.append(["hash", self.hash, True, (bool)])
        self.__arg_info_matrix.append(["delimiter", self.delimiter, True, (str)])
        self.__arg_info_matrix.append(["data_sequence_column", self.data_sequence_column, True, (str,list)])
        
        # Perform the function validations
        self.__validate()
        # Generate the ML query
        self.__form_tdml_query()
        # Execute ML query
        self.__execute()
        
    def __validate(self):
        """
        Function to validate sqlmr function arguments, which verifies missing 
        arguments, input argument and table types. Also processes the 
        argument values.
        """
        
        # Make sure that a non-NULL value has been supplied for all mandatory arguments
        self.__awu._validate_missing_required_arguments(self.__arg_info_matrix)
        
        # Make sure that a non-NULL value has been supplied correct type of argument
        self.__awu._validate_argument_types(self.__arg_info_matrix)
        
        # Check to make sure input table types are strings or data frame objects or of valid type.
        self.__awu._validate_input_table_datatype(self.data, "data", None)
        
        # Check whether the input columns passed to the argument are not empty.
        # Also check whether the input columns passed to the argument valid or not.
        self.__awu._validate_input_columns_not_empty(self.seq_column, "seq_column")
        self.__awu._validate_dataframe_has_argument_columns(self.seq_column, "seq_column", self.data, "data", False)
        
        self.__awu._validate_input_columns_not_empty(self.count_column, "count_column")
        self.__awu._validate_dataframe_has_argument_columns(self.count_column, "count_column", self.data, "data", False)
        
        self.__awu._validate_input_columns_not_empty(self.data_sequence_column, "data_sequence_column")
        self.__awu._validate_dataframe_has_argument_columns(self.data_sequence_column, "data_sequence_column", self.data, "data", False)
        
        
    def __form_tdml_query(self):
        """
        Function to generate the analytical function queries. The function defines 
        variables and list of arguments required to form the query.
        """
        # Generate temp table names for output table parameters if any.
        self.__output_table_temp_tablename = UtilFuncs._generate_temp_table_name(prefix = "td_pathanalyzer0", use_default_database = True, gc_on_quit = True, quote=False, table_type = TeradataConstants.TERADATA_TABLE)
        
        # Output table arguments list
        self.__func_output_args_sql_names = ["OutputTable"]
        self.__func_output_args = [self.__output_table_temp_tablename]
        
        # Generate lists for rest of the function arguments
        self.__func_other_arg_sql_names = []
        self.__func_other_args = []
        self.__func_other_arg_json_datatypes = []
        
        self.__func_other_arg_sql_names.append("SeqColumn")
        self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(UtilFuncs._teradata_quote_arg(self.seq_column,"\""),"'"))
        self.__func_other_arg_json_datatypes.append("COLUMN_NAMES")
        
        self.__func_other_arg_sql_names.append("CountColumn")
        self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(UtilFuncs._teradata_quote_arg(self.count_column,"\""),"'"))
        self.__func_other_arg_json_datatypes.append("COLUMN_NAMES")
        
        if self.hash is not None and self.hash != False:
            self.__func_other_arg_sql_names.append("HashCode")
            self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(self.hash,"'"))
            self.__func_other_arg_json_datatypes.append("BOOLEAN")
        
        if self.delimiter is not None and self.delimiter != ",":
            self.__func_other_arg_sql_names.append("Delimiter")
            self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(self.delimiter,"'"))
            self.__func_other_arg_json_datatypes.append("STRING")
        
        # Generate lists for rest of the function arguments
        sequence_input_by_list = []
        if self.data_sequence_column is not None:
            sequence_input_by_list.append("InputTable:" + UtilFuncs._teradata_collapse_arglist(self.data_sequence_column,""))
        
        if len(sequence_input_by_list) > 0:
            self.__func_other_arg_sql_names.append("SequenceInputBy")
            self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(sequence_input_by_list,"'"))
            self.__func_other_arg_json_datatypes.append("STRING")
        
        
        # Declare empty lists to hold input table information.
        self.__func_input_arg_sql_names = []
        self.__func_input_table_view_query = []
        self.__func_input_dataframe_type = []
        self.__func_input_distribution = []
        self.__func_input_partition_by_cols = []
        self.__func_input_order_by_cols = []
        
        # Process data
        self.__table_ref = self.__awu._teradata_on_clause_from_dataframe(self.data, False)
        self.__func_input_distribution.append("NONE")
        self.__func_input_arg_sql_names.append("InputTable")
        self.__func_input_table_view_query.append(self.__table_ref["ref"])
        self.__func_input_dataframe_type.append(self.__table_ref["ref_type"])
        self.__func_input_partition_by_cols.append("NA_character_")
        self.__func_input_order_by_cols.append("NA_character_")
        
        function_name = "PathAnalyzer"
        # Create instance to generate SQLMR.
        aqg_obj = AnalyticQueryGenerator(function_name 
                ,self.__func_input_arg_sql_names 
                ,self.__func_input_table_view_query 
                ,self.__func_input_dataframe_type 
                ,self.__func_input_distribution 
                ,self.__func_input_partition_by_cols 
                ,self.__func_input_order_by_cols 
                ,self.__func_other_arg_sql_names 
                ,self.__func_other_args 
                ,self.__func_other_arg_json_datatypes 
                ,self.__func_output_args_sql_names 
                ,self.__func_output_args)
        # Invoke call to SQL-MR generation.
        self.sqlmr_query = aqg_obj._gen_sqlmr_select_stmt_sql()
        
        # Print SQL-MR query if requested to do so.
        if display.print_sqlmr_query:
            print(self.sqlmr_query)
        
    def __execute(self):
        """
        Function to execute SQL-MR queries. 
        Create DataFrames for the required SQL-MR outputs.
        """
        # Generate STDOUT table name and add it to the output table list.
        sqlmr_stdout_temp_tablename = UtilFuncs._generate_temp_table_name(prefix = "td_sqlmr_out_", use_default_database = True, gc_on_quit = True, quote=False, table_type = TeradataConstants.TERADATA_TABLE)
        try:
            # TODO:: Table needs to be created once ANLY-7676 is fixed.
            #UtilFuncs._create_table(sqlmr_stdout_temp_tablename, self.sqlmr_query)
            UtilFuncs._execute_query(self.sqlmr_query)
        except Exception as emsg:
            raise TeradataMlException(Messages.get_message(MessageCodes.TDMLDF_EXEC_SQL_FAILED, str(emsg)), MessageCodes.TDMLDF_EXEC_SQL_FAILED)
        
        # Update output table data frames.
        self._mlresults = []
        self.output_table = self.__awu._create_data_set_object(df_input=UtilFuncs._extract_table_name(self.__output_table_temp_tablename), source_type="table", database_name=UtilFuncs._extract_db_name(self.__output_table_temp_tablename))
        # TODO:: Following line must be un-commented, once ANLY-7676 is fixed.
        #self.output = self.__awu._create_data_set_object(df_input=UtilFuncs._extract_table_name(sqlmr_stdout_temp_tablename), source_type="table", database_name=UtilFuncs._extract_db_name(sqlmr_stdout_temp_tablename))
        self._mlresults.append(self.output_table)
        #self._mlresults.append(self.output)
        
    def __repr__(self):
        """
        Returns the string representation for a PathAnalyzer class instance.
        """
        # TODO:: Following lines of comments needs to be enabled, once ANLY-7676 is fixed.
        repr_string = ""
        #repr_string="############ STDOUT Output ############"
        #repr_string = "{}\n\n{}".format(repr_string,self.output)
        repr_string="{}\n\n\n############ output_table Output ############".format(repr_string)
        repr_string = "{}\n\n{}".format(repr_string,self.output_table)
        return repr_string

==> teradataml-16.20.0.3-py3-none-any.whl: teradataml/analytics/mle/PathAnalyzer.py <==
#!/usr/bin/python
# ################################################################## 
# 
# Copyright 2018 Teradata. All rights reserved.
# TERADATA CONFIDENTIAL AND TRADE SECRET
# 
# Primary Owner: Pankaj Purandare (pankajvinod.purandare@teradata.com)
# Secondary Owner: Mounika Kotha (mounika.kotha@teradata.com)
# 
# Version: 1.2
# Function Version: 1.9
# 
# ################################################################## 

import inspect
from teradataml.common.wrapper_utils import AnalyticsWrapperUtils
from teradataml.common.utils import UtilFuncs
from teradataml.context.context import *
from teradataml.dataframe.dataframe import DataFrame
from teradataml.common.aed_utils import AedUtils
from teradataml.analytics.analytic_query_generator import AnalyticQueryGenerator
from teradataml.common.exceptions import TeradataMlException
from teradataml.common.messages import Messages
from teradataml.common.messagecodes import MessageCodes
from teradataml.common.constants import TeradataConstants
from teradataml.dataframe.dataframe_utils import DataFrameUtils as df_utils
from teradataml.options.display import display

class PathAnalyzer:
    
    def __init__(self,
        data = None,
        seq_column = None,
        count_column = None,
        hash = False,
        delimiter = ",",
        data_sequence_column = None):
        """
        DESCRIPTION:
            This function generates the children, parent for a particular node and
            calculates its depth and number of visits.
            The PathAnalyzer function:
                - Inputs a set of paths to the PathGenerator function.
                - Inputs the output to the PathSummarizer function.
                - Inputs the output to the PathStart function, which outputs, for each
                parent, all children and the number of times that the user traveled
                each child.


        PARAMETERS:
            data:
                Required Argument.
                Specifies either the name of the input teradataml DataFrame
                or processed NPath output. The input teradataml DataFrame contains
                the paths to analyze. Each path is a string of alphanumeric symbols
                that represents an ordered sequence of page views (or actions).
                Typically, each symbol is a code that represents a unique page
                view.
                If you would like to use output of NPath, then it must be processed
                to select two columns; the column that contains the paths
                (seq_column) and the column that contains the number of times
                a path was traveled (count_column), which should be grouped by
                seq_column, so that the input teradataml DataFrame has
                one row for each unique path traveled on a web site.

            seq_column:
                Required Argument.
                Specifies the name of the input teradataml DataFrame column that
                contains the paths.
                Types: str

            count_column:
                Required Argument.
                Specifies the name of the input teradataml DataFrame column that
                contains the number of times a path was traveled.
                Types: str

            hash:
                Optional Argument.
                Specifies whether to include the hash code of the output column node.
                Default Value: False
                Types: bool

            delimiter:
                Optional Argument.
                Specifies the single-character delimiter that separates symbols in
                the path string.
                Note: Do not use any of the following characters as delimiter
                      (they cause the function to fail):
                          Asterisk (*), Plus (+), Left parenthesis ((), Right parenthesis ()),
                          Single quotation mark ('), Escaped single quotation mark (\\'),
                          Backslash (\\)
                Default Value: ","
                Types: str

            data_sequence_column:
                Optional Argument.
                Specifies the list of column(s) that uniquely identifies each row of
                the input argument "data". The argument is used to ensure
                deterministic results for functions which produce results that vary
                from run to run.
                Types: str OR list of Strings (str)

        RETURNS:
            Instance of PathAnalyzer.
            Output teradataml DataFrames can be accessed using attribute
            references, such as PathAnalyzerObj.<attribute_name>.
            Output teradataml DataFrame attribute name is:
                output_table


        RAISES:
            TeradataMlException


        EXAMPLES:
            # Load example data.
            load_example_data("pathanalyzer", "clickstream1")

            # Create teradataml DataFrame objects.
            # The table contains clickstream data, where the "path" column
            # contains symbols for the pages that the customer clicked.
            clickstream1 = DataFrame.from_table("clickstream1")

            # Example 1 - Let's analyze the Paths taken for a parent, children
            #             in this clickstream data, to reach to a page.
            PathAnalyzer_out = PathAnalyzer(data = clickstream1,
                                            seq_column = "path",
                                            count_column = "cnt",
                                            hash = False,
                                            delimiter = ","
                                            )

            # Print the results
            PathAnalyzer_out
        
        """
        self.data  = data 
        self.seq_column  = seq_column 
        self.count_column  = count_column 
        self.hash  = hash 
        self.delimiter  = delimiter 
        self.data_sequence_column  = data_sequence_column 
        
        # Create TeradataPyWrapperUtils instance which contains validation functions.
        self.__awu = AnalyticsWrapperUtils()
        self.__aed_utils = AedUtils()
        
        # Create argument information matrix to do parameter checking
        self.__arg_info_matrix = []
        self.__arg_info_matrix.append(["data", self.data, False, (DataFrame)])
        self.__arg_info_matrix.append(["seq_column", self.seq_column, False, (str)])
        self.__arg_info_matrix.append(["count_column", self.count_column, False, (str)])
        self.__arg_info_matrix.append(["hash", self.hash, True, (bool)])
        self.__arg_info_matrix.append(["delimiter", self.delimiter, True, (str)])
        self.__arg_info_matrix.append(["data_sequence_column", self.data_sequence_column, True, (str,list)])
        
        if inspect.stack()[1][3] != '_from_model_manager':
            # Perform the function validations
            self.__validate()
            # Generate the ML query
            self.__form_tdml_query()
            # Execute ML query
            self.__execute()
        
    def __validate(self):
        """
        Function to validate sqlmr function arguments, which verifies missing 
        arguments, input argument and table types. Also processes the 
        argument values.
        """
        
        # Make sure that a non-NULL value has been supplied for all mandatory arguments
        self.__awu._validate_missing_required_arguments(self.__arg_info_matrix)
        
        # Make sure that a non-NULL value has been supplied correct type of argument
        self.__awu._validate_argument_types(self.__arg_info_matrix)
        
        # Check to make sure input table types are strings or data frame objects or of valid type.
        self.__awu._validate_input_table_datatype(self.data, "data", None)
        
        # Check whether the input columns passed to the argument are not empty.
        # Also check whether the input columns passed to the argument valid or not.
        self.__awu._validate_input_columns_not_empty(self.seq_column, "seq_column")
        self.__awu._validate_dataframe_has_argument_columns(self.seq_column, "seq_column", self.data, "data", False)
        
        self.__awu._validate_input_columns_not_empty(self.count_column, "count_column")
        self.__awu._validate_dataframe_has_argument_columns(self.count_column, "count_column", self.data, "data", False)
        
        self.__awu._validate_input_columns_not_empty(self.data_sequence_column, "data_sequence_column")
        self.__awu._validate_dataframe_has_argument_columns(self.data_sequence_column, "data_sequence_column", self.data, "data", False)
        
        
    def __form_tdml_query(self):
        """
        Function to generate the analytical function queries. The function defines 
        variables and list of arguments required to form the query.
        """
        # Generate temp table names for output table parameters if any.
        self.__output_table_temp_tablename = UtilFuncs._generate_temp_table_name(prefix = "td_pathanalyzer0", use_default_database = True, gc_on_quit = True, quote=False, table_type = TeradataConstants.TERADATA_TABLE)
        
        # Output table arguments list
        self.__func_output_args_sql_names = ["OutputTable"]
        self.__func_output_args = [self.__output_table_temp_tablename]
        
        # Generate lists for rest of the function arguments
        self.__func_other_arg_sql_names = []
        self.__func_other_args = []
        self.__func_other_arg_json_datatypes = []
        
        self.__func_other_arg_sql_names.append("SeqColumn")
        self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(UtilFuncs._teradata_quote_arg(self.seq_column,"\""),"'"))
        self.__func_other_arg_json_datatypes.append("COLUMN_NAMES")
        
        self.__func_other_arg_sql_names.append("CountColumn")
        self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(UtilFuncs._teradata_quote_arg(self.count_column,"\""),"'"))
        self.__func_other_arg_json_datatypes.append("COLUMN_NAMES")
        
        if self.hash is not None and self.hash != False:
            self.__func_other_arg_sql_names.append("HashCode")
            self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(self.hash,"'"))
            self.__func_other_arg_json_datatypes.append("BOOLEAN")
        
        if self.delimiter is not None and self.delimiter != ",":
            self.__func_other_arg_sql_names.append("Delimiter")
            self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(self.delimiter,"'"))
            self.__func_other_arg_json_datatypes.append("STRING")
        
        # Generate lists for rest of the function arguments
        sequence_input_by_list = []
        if self.data_sequence_column is not None:
            sequence_input_by_list.append("InputTable:" + UtilFuncs._teradata_collapse_arglist(self.data_sequence_column,""))
        
        if len(sequence_input_by_list) > 0:
            self.__func_other_arg_sql_names.append("SequenceInputBy")
            self.__func_other_args.append(UtilFuncs._teradata_collapse_arglist(sequence_input_by_list,"'"))
            self.__func_other_arg_json_datatypes.append("STRING")
        
        
        # Declare empty lists to hold input table information.
        self.__func_input_arg_sql_names = []
        self.__func_input_table_view_query = []
        self.__func_input_dataframe_type = []
        self.__func_input_distribution = []
        self.__func_input_partition_by_cols = []
        self.__func_input_order_by_cols = []
        
        # Process data
        self.__table_ref = self.__awu._teradata_on_clause_from_dataframe(self.data, False)
        self.__func_input_distribution.append("NONE")
        self.__func_input_arg_sql_names.append("InputTable")
        self.__func_input_table_view_query.append(self.__table_ref["ref"])
        self.__func_input_dataframe_type.append(self.__table_ref["ref_type"])
        self.__func_input_partition_by_cols.append("NA_character_")
        self.__func_input_order_by_cols.append("NA_character_")
        
        function_name = "PathAnalyzer"
        # Create instance to generate SQLMR.
        aqg_obj = AnalyticQueryGenerator(function_name 
                ,self.__func_input_arg_sql_names 
                ,self.__func_input_table_view_query 
                ,self.__func_input_dataframe_type 
                ,self.__func_input_distribution 
                ,self.__func_input_partition_by_cols 
                ,self.__func_input_order_by_cols 
                ,self.__func_other_arg_sql_names 
                ,self.__func_other_args 
                ,self.__func_other_arg_json_datatypes 
                ,self.__func_output_args_sql_names 
                ,self.__func_output_args 
                ,engine = "ENGINE_ML")
        # Invoke call to SQL-MR generation.
        self.sqlmr_query = aqg_obj._gen_sqlmr_select_stmt_sql()
        
        # Print SQL-MR query if requested to do so.
        if display.print_sqlmr_query:
            print(self.sqlmr_query)
        
    def __execute(self):
        """
        Function to execute SQL-MR queries. 
        Create DataFrames for the required SQL-MR outputs.
        """
        # Generate STDOUT table name and add it to the output table list.
        sqlmr_stdout_temp_tablename = UtilFuncs._generate_temp_table_name(prefix = "td_sqlmr_out_", use_default_database = True, gc_on_quit = True, quote=False, table_type = TeradataConstants.TERADATA_TABLE)
        try:
            # TODO:: Table needs to be created once ANLY-7676 is fixed.
            #UtilFuncs._create_table(sqlmr_stdout_temp_tablename, self.sqlmr_query)
            UtilFuncs._execute_query(self.sqlmr_query)
        except Exception as emsg:
            raise TeradataMlException(Messages.get_message(MessageCodes.TDMLDF_EXEC_SQL_FAILED, str(emsg)), MessageCodes.TDMLDF_EXEC_SQL_FAILED)
        
        # Update output table data frames.
        self._mlresults = []
        self.output_table = self.__awu._create_data_set_object(df_input=UtilFuncs._extract_table_name(self.__output_table_temp_tablename), source_type="table", database_name=UtilFuncs._extract_db_name(self.__output_table_temp_tablename))
        # TODO:: Following line must be un-commented, once ANLY-7676 is fixed.
        #self.output = self.__awu._create_data_set_object(df_input=UtilFuncs._extract_table_name(sqlmr_stdout_temp_tablename), source_type="table", database_name=UtilFuncs._extract_db_name(sqlmr_stdout_temp_tablename))
        self._mlresults.append(self.output_table)
        #self._mlresults.append(self.output)
        
    @classmethod
    def _from_model_manager(cls,
        output_table = None,
        #output = None,
        **kwargs):
        """
        Classmethod which will be used by Model Manager, to instantiate this wrapper class.
        """
        kwargs.pop("output_table", None)
        #kwargs.pop("output", None)
        
        # Let's create an object of this class.
        obj = cls(**kwargs)
        obj.output_table  = output_table 
        #obj.output  = output
        
        # Update output table data frames.
        obj._mlresults = []
        obj.output_table = obj.__awu._create_data_set_object(df_input=UtilFuncs._extract_table_name(obj.output_table), source_type="table", database_name=UtilFuncs._extract_db_name(obj.output_table))
        #obj.output = obj.__awu._create_data_set_object(df_input=UtilFuncs._extract_table_name(obj.output), source_type="table", database_name=UtilFuncs._extract_db_name(obj.output))
        obj._mlresults.append(obj.output_table)
        #obj._mlresults.append(obj.output)
        return obj
        
    def __repr__(self):
        """
        Returns the string representation for a PathAnalyzer class instance.
        """
        # TODO:: Following lines of comments needs to be enabled, once ANLY-7676 is fixed.
        repr_string = ""
        #repr_string="############ STDOUT Output ############"
        #repr_string = "{}\n\n{}".format(repr_string,self.output)
        repr_string="{}\n\n\n############ output_table Output ############".format(repr_string)
        repr_string = "{}\n\n{}".format(repr_string,self.output_table)
        return repr_string
